<?php

class Crud extends CI_Model
{

  public function check_uid($uid)
  {
    return $this->db->where('product_uid', $uid)->count_all_results('products');
  }

  public function search($q)
  {
    $qarray = explode(' ', $q);

    $this->db->distinct();
    $this->db->select('*');
    $this->db->from('products');
    $this->db->like('product_name', $q, 'both');
    if (count($qarray) > 1) {
      foreach ($qarray as $s) {
        $this->db->or_like('product_summery', $s, 'both');
        $this->db->or_like('product_micro_details', $s, 'both');
        $this->db->or_like('product_seo_title', $s, 'both');
        $this->db->or_like('product_seo_description', $s, 'both');
        $this->db->or_like('product_seo_keyword', $s, 'both');
      }
    } else {
      $this->db->or_like('product_summery', $q, 'both');
      $this->db->or_like('product_micro_details', $q, 'both');
      $this->db->or_like('product_seo_title', $q, 'both');
      $this->db->or_like('product_seo_description', $q, 'both');
      $this->db->or_like('product_seo_keyword', $q, 'both');
    }

    $query = $this->db->get();
    $sr = $query->result();
    if (count($sr) > 0) {
      foreach ($sr as $r) {
        echo '<a href="' . base_url($r->product_vanity_url) . '.html" class="list-group-item list-group-item-action list-group-item-info">' . $r->product_name . '</a>';
      }
    } else {
      echo '<span class="list-group-item list-group-item-action list-group-item-warning">Unable to find any product related to your query <span class="font-weight-bolder text-danger">"' . $q . '"</span></span>';
    }
  }

  public function check_category_name($category_vanity_url)
  {
    $this->db->from('category');
    $this->db->where('category_vanity_url', $category_vanity_url);
    $query = $this->db->get();
    $result = $query->row();
    return $result;
  }

  public function check_product_name($product_vanity_url)
  {
    $this->db->from('products');
    $this->db->where('product_vanity_url', $product_vanity_url);
    $query = $this->db->get();
    $result = $query->row();
    return $result;
  }
  public function check_page_name($pageNamel)
  {
    $this->db->from('pages');
    $this->db->where('pageName', $pageNamel);
    $query = $this->db->get();
    $result = $query->row();
    return $result;
  }

  public function getDataAll($table, $orderByCol = null, $order = null)
  {
    $this->db->from($table);
    if (isset($orderByCol) && isset($order)) {
      $this->db->order_by($orderByCol, $order);
    }
    $query = $this->db->get();

    $result = $query->result();
    return $result;
  }

  public function getSortedPageDataForMenu()
  {
    $this->db->from('pages');
    $this->db->where('showInMenu', 'yes');
    $this->db->order_by('pagePosition', 'ASC');
    $query = $this->db->get();
    return $query->result();
  }

  public function getDataSingle($table, $id, $idname = null, $all = null, $pageName = null)
  {
    $this->db->from($table);

    if ($pageName != null) {
      $this->db->where('pageName', $pageName);
    }
    if ($idname != null) {
      $this->db->where($idname, $id);
    } else {
      $this->db->where('id', $id);
    }
    $query = $this->db->get();
    if ($all == true) {
      $result = $query->result();
    } else {
      $result = $query->row();
    }
    return $result;
  }

  public function getStaticContent($contentPositionId, $pageName)
  {
    $this->db->from('content');
    $this->db->where('contentPositionId', $contentPositionId);
    $this->db->where('pageName', $pageName);
    $query = $this->db->get();
    $result = $query->row();
    return $result->content;
  }

  public function getProductListbyCatID($childCatID)
  {
    $this->db->from('products');
    $this->db->where('category_id', $childCatID);
    $query = $this->db->get();
    $result = $query->result();
    return $result;
  }

  public function getVanityURLId($catID)
  {
    return $this->db->get_where('category', ['id' => $catID])->row('category_vanity_url');
  }

  public function getIdByVanityURL($catVanityURL)
  {
    return $this->db->get_where('category', ['category_vanity_url' => $catVanityURL])->row('id');
  }

  public function getChildCategory($parent_id = null, $limit = null, $featured = null)
  {
    $this->db->from('category');
    $this->db->where('type', 'child');
    $this->db->where('status', 'yes');
    if ($featured == true) {
      $this->db->where('featured', 'yes');
    }
    if ($parent_id != null) {
      $this->db->where('parent_id', $parent_id);
    }
    if ($limit != null) {
      $this->db->limit($limit);
    }
    $query = $this->db->get();
    return $query->result();
  }
  public function getParentCategory($limit = null)
  {
    $this->db->from('category');
    $this->db->where('type', 'parent');
    $this->db->where('parent_id', null);
    $this->db->where('status', 'yes');
    if ($limit != null) {
      $this->db->limit($limit);
    }
    $query = $this->db->get();
    return $query->result();
  }

  public function getCategorySingleData($id, $type = null)
  {
    $this->db->from('category');
    if($type != null)
    {
      $this->db->where('type', $type);
    }
    $this->db->where('id', $id);
    $this->db->where('status', 'yes');
    $query = $this->db->get();
    return $query->row();
  }

  public function getCategory($option = null, $parent_id = null, $order = null)
  {
    $this->db->from('category');

    if ($option == 'parent') {
      $this->db->where('type', 'parent');
    } else if ($option == 'child') {
      $this->db->where('type', 'child');
    }
    if ($parent_id != null) {
      $this->db->where('id', $parent_id);
      $this->db->where('status', 'yes');
      $query = $this->db->get();
      return $query->row();
    } else {
      if ($order == 'desc') {
        $this->db->order_by("id", "desc");
      } else {
        $this->db->order_by("id", "asc");
      }
      $query = $this->db->get();
      return $query->result();
    }
  }

  public function save($table, $data, $getId)
  {
    if ($this->db->insert($table, $data)) {
      if ($getId == true) {
        return $this->db->insert_id();
      } else if ($getId == true) {
        return true;
      }
    } else {
      return false;
    }
  }

  public function update($table, $idkey, $id, $data)
  {
    $this->db->where($idkey, $id);
    if ($this->db->update($table, $data)) {
      return true;
    } else {
      return false;
    }
  }

  public function updateProductViews($product_id, $showStatus = null)
  {
    $getPrevViews = $this->db->get_where('products', ['product_id' => $product_id])->row('product_views');
    if($showStatus == true)
    {
      return $getPrevViews;
      exit;
    }
    $addView = $getPrevViews + 1;
    $this->db->where('product_id', $product_id);
    $this->db->update('products', ['product_views' => $addView]);
  }

  public function getPopularProducts(){
    $this->db->select('*');
    $this->db->from('products');
    $this->db->where('product_views > ', 0);
    $this->db->order_by("product_views","DESC");
    $this->db->limit('6');
    $query = $this->db->get();
    return $query->result();
  }

  public function getLastPositionData()
  {
    $this->db->from('pages');
    $this->db->order_by("pagePosition", "desc");
    $result = $this->db->get();
    return $result->row('pagePosition');
  }

  public function delete($table, $idkey, $id)
  {
    $this->db->where($idkey, $id);
    if ($this->db->delete($table)) {
      return true;
    } else {
      return false;
    }
  }

  function save_upload($title, $image)
  {
    $data = array(
      'title'     => $title,
      'file'      => $image
    );
    $result = $this->db->insert('media', $data);
    return $result;
  }

  function verify($username, $password)
  {
    // $this->db->from('users');
    // $this->db->where('username', $username);
    // $this->db->where('password', $password);
    $resultCount = $this->db->where(['username'=>$username, 'password'=>$password])->count_all_results('users');
    if ($resultCount > 0) {
      return true;
    } else {
      return false;
    }
  }

  function deletePage($id)
  {
    $this->db->where('pageId', $id);
    if ($this->db->delete('pages')) {
      return true;
    } else {
      return false;
    }
  }

  public function getCount($table, $colName, $colVal)
  {
    return $this->db->where($colName, $colVal)->count_all_results($table);
  }

  // Product Filter Page
  public function fetch_filter_type($type)
  {
    $this->db->distinct();
    $this->db->select($type);
    $this->db->from("products");
    $this->db->where('product_status', 'active');
    return $this->db->get();
  }

  function make_query($minimum_price, $maximum_price, $category, $stock)
  {
    $query = "SELECT * FROM products WHERE product_status = 'active'";

    if(isset($minimum_price, $maximum_price) && !empty($minimum_price) &&  !empty($maximum_price))
    {
     $query .= " AND product_price BETWEEN '".$minimum_price."' AND '".$maximum_price."'";
    }

    if(isset($category))
    {
     $category_filter = implode("','", $category);
     $query .= " AND category_id IN('".$category_filter."')";
    }

    if(isset($stock))
    {
     $stock_filter = implode("','", $stock);
     $query .= " AND product_availability IN('".$stock_filter."')";
    }

    return $query;
  }

 function count_all($minimum_price, $maximum_price, $category, $stock)
 {
  $query = $this->make_query($minimum_price, $maximum_price, $category, $stock);
  $data = $this->db->query($query);
  return $data->num_rows();
 }

 function fetch_data($limit, $start, $minimum_price, $maximum_price, $category, $stock)
 {
  $query = $this->make_query($minimum_price, $maximum_price, $category, $stock);

  $query .= ' LIMIT '.$start.', ' . $limit;

  $data = $this->db->query($query);

  $output = '';
  if($data->num_rows() > 0)
  {
   foreach($data->result_array() as $row)
   {
     if($row['product_in_sale'] === 'yes')
     {
       $product_in_sale = '
       <span class="onsale">
           <span>Sale!</span>
       </span>
       ';
     }
     else{
       $product_in_sale = '';
     }

     if($row['product_availability'] === 'true')
     {
       $stock_status = '
       <span class="price">₹ '. number_format($row['product_price'], 2) .'</span>
       <span class="regular-price">₹ '. number_format($row['product_price_mrp'], 2) .'</span>
       ';
     }
     else{
       $stock_status = '
       <span class="price text-danger">Out Of Stock</span>
       ';
     }

    $output .= '
    <div class="col-lg-4 col-xl-3 col-md-4 product__box__container">

      <div class="single-product mb-40">
        <div class="single-product">
          <div class="product-img">
            <a href="'.base_url($row['product_vanity_url']).'.html">
            <img src="'.$row['product_img_one'] .'" alt="'. $row['product_name'] .'">
            </a>
            '.$product_in_sale.'
            <div class="product-action">
              <ul>
                <li>
                  <a href="'.base_url($row['product_vanity_url']).'.html" data-toggle="tooltip" title="" data-original-title="Add To Cart">
                    <i class="fa fa-shopping-cart"></i>
                  </a>
                </li>
              </ul>
            </div>
          </div>
          <div class="product-content">
            <h4>
              <a href="'.base_url($row['product_vanity_url']).'.html">
                '. $row['product_name'] .'
              </a>
            </h4>
          </div>
          <div class="product-price">
            '.$stock_status.'
          </div>
        </div>
      </div>
    </div>
    <!--Single Product End-->
    ';
   }
  }
  else
  {
   $output = '<div class="col-12 text-center">
     <div class="alert alert-warning">
      <h3 class="pt-3"><i class="fas fa-search"></i> Sorry, Unable to find any product.</h3>
      <br />
      <p><a href="'.base_url('shop.html').'" class="btn btn-warning">Browse All Products</a></p>
     </div>
   </div>';
  }
  return $output;
 }

}
